Simmate Configuration
---------------------

This module sets up Simmate and other programs it depends on. It also includes an example config directory and example custom project. These example directories are only available through [github](https://github.com/jacksund/simmate/tree/main/src/simmate/configuration) and not the API documentation.
